@@ -20,10 +20,12 @@
 
 ### Code:
 
-package Tree::Range::base 0.21;
+package Tree::Range::base;
 
 use strict;
 
+our $VERSION = 0.22;
+
 require Carp;
 
 use Scalar::Util qw (refaddr);
